@@ -7,7 +7,7 @@ Command line options.
 .. versionadded:: 0.4.0
 """
 #
-#  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -64,7 +64,6 @@ from typing import Any, Callable, Iterable, List, Optional, Tuple, TypeVar, cast
 
 # 3rd party
 import click
-from click import Argument, Context, IntRange, Option, OptionParser
 from click.decorators import _param_memo  # type: ignore
 
 # this package
@@ -81,6 +80,8 @@ __all__ = [
 		"flag_option",
 		"auto_default_option",
 		"auto_default_argument",
+		"_A",
+		"_C",
 		]
 
 _A = TypeVar("_A", bound=click.Argument)
@@ -97,7 +98,8 @@ class VerboseVersionCountType(click.IntRange):
 	def __init__(self):
 		super().__init__(min=0)
 
-	def _describe_range(self):
+	@staticmethod
+	def _describe_range():  # pragma: no cover
 		"""
 		Describe the range for use in help text.
 		"""
@@ -105,7 +107,7 @@ class VerboseVersionCountType(click.IntRange):
 		return ''
 
 
-def verbose_option(help_text: str = "Show verbose output.") -> Callable[..., click.Command]:
+def verbose_option(help_text: str = "Show verbose output.") -> Callable[[_C], _C]:
 	"""
 	Adds an option (via the parameter ``verbose``: :class:`int`) to enable verbose output.
 
@@ -119,7 +121,7 @@ def verbose_option(help_text: str = "Show verbose output.") -> Callable[..., cli
 	return click.option("-v", "--verbose", count=True, help=help_text, type=VerboseVersionCountType())
 
 
-def version_option(callback: Callable[[Context, Option, int], Any]) -> Callable[..., click.Command]:
+def version_option(callback: Callable[[click.Context, click.Option, int], Any]) -> Callable[[_C], _C]:
 	"""
 	Adds an option to show the version and exit.
 
@@ -158,7 +160,7 @@ def version_option(callback: Callable[[Context, Option, int], Any]) -> Callable[
 			)
 
 
-def colour_option(help_text="Whether to use coloured output.") -> Callable[..., click.Command]:
+def colour_option(help_text="Whether to use coloured output.") -> Callable[[_C], _C]:
 	"""
 	Adds an option (via the parameter ``colour``: :class:`bool`) to enable verbose output.
 
@@ -174,7 +176,7 @@ def colour_option(help_text="Whether to use coloured output.") -> Callable[...,
 			)
 
 
-def force_option(help_text: str) -> Callable[..., click.Command]:
+def force_option(help_text: str) -> Callable[[_C], _C]:
 	"""
 	Decorator to add the ``-f / --force`` option to a click command.
 
@@ -188,7 +190,7 @@ def force_option(help_text: str) -> Callable[..., click.Command]:
 	return flag_option("-f", "--force", help=help_text)
 
 
-def no_pager_option(help_text="Disable the output pager.") -> Callable[..., click.Command]:
+def no_pager_option(help_text="Disable the output pager.") -> Callable[[_C], _C]:
 	"""
 	Decorator to add the ``--no-pager`` option to a click command.
 
@@ -202,7 +204,7 @@ def no_pager_option(help_text="Disable the output pager.") -> Callable[..., clic
 	return flag_option("--no-pager", help=help_text)
 
 
-def flag_option(*args, default: Optional[bool] = False, **kwargs) -> Callable[..., click.Command]:
+def flag_option(*args, default: Optional[bool] = False, **kwargs) -> Callable[[_C], _C]:
 	r"""
 	Decorator to a flag option to a click command.
 
@@ -221,7 +223,7 @@ def flag_option(*args, default: Optional[bool] = False, **kwargs) -> Callable[..
 			)
 
 
-def auto_default_option(*param_decls, **attrs) -> Callable[..., click.Command]:
+def auto_default_option(*param_decls, **attrs) -> Callable[[_C], _C]:
 	"""
 	Attaches an option to the command, with a default value determined from the decorated function's signature.
 
@@ -241,7 +243,7 @@ def auto_default_option(*param_decls, **attrs) -> Callable[..., click.Command]:
 		if "help" in option_attrs:
 			option_attrs["help"] = inspect.cleandoc(option_attrs["help"])
 
-		OptionClass = option_attrs.pop("cls", Option)
+		OptionClass = option_attrs.pop("cls", click.Option)
 
 		option = OptionClass(param_decls, **option_attrs)
 		_param_memo(f, option)
@@ -264,14 +266,14 @@ def _get_default_from_callback_and_set(command: click.Command, param: click.Para
 			param.default = param_default
 
 
-def auto_default_argument(*param_decls, **attrs) -> Callable[..., click.Argument]:
+def auto_default_argument(*param_decls, **attrs) -> Callable[[_C], _C]:
 	"""
 	Attaches an argument to the command, with a default value determined from the decorated function's signature.
 
 	All positional arguments are passed as parameter declarations to :class:`click.Argument`;
 	all keyword arguments are forwarded unchanged (except ``cls``).
 	This is equivalent to creating an :class:`click.Argument` instance manually
-	and attaching it to the :attr:`click.Argument.params` list.
+	and attaching it to the :attr:`click.Command.params` list.
 
 	.. versionadded:: 0.8.0
 
@@ -279,7 +281,7 @@ def auto_default_argument(*param_decls, **attrs) -> Callable[..., click.Argument
 	"""
 
 	def decorator(f: _C) -> _C:
-		ArgumentClass = attrs.pop("cls", Argument)
+		ArgumentClass = attrs.pop("cls", click.Argument)
 		argument = ArgumentClass(param_decls, **attrs)
 		_param_memo(f, argument)
 
@@ -296,7 +298,7 @@ class MultiValueOption(click.Option):
 
 	:param param_decls: The parameter declarations for this option or argument.
 		This is a list of flags or argument names.
-	:param show_default: Controls if the default value should be shown on the help page.
+	:param show_default: Controls whether the default value should be shown on the help page.
 		Normally, defaults are not shown.
 		If this value is a string, it shows the string instead of the value.
 		This is particularly useful for dynamic options.
@@ -363,7 +365,7 @@ class MultiValueOption(click.Option):
 		self._previous_parser_process: Optional[Callable] = None
 		self._eat_all_parser: Optional[click.parser.Option] = None
 
-	def add_to_parser(self, parser: OptionParser, ctx: Context):
+	def add_to_parser(self, parser: click.OptionParser, ctx: click.Context):
 		"""
 		Add the :class:`~.MultiValueOption` to the given parser.
 
