@@ -3,6 +3,12 @@
 #  utils.py
 """
 Utility functions.
+
+.. versionchanged:: 1.0.0
+
+	:func:`~.tracebacks.traceback_handler` and :func:`~.tracebacks.handle_tracebacks`
+	moved to :mod:`consolekit.tracebacks`.
+	They will still be importable from here until v2.0.0
 """
 #
 #  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -30,14 +36,14 @@ Utility functions.
 import contextlib
 import difflib
 import os
-import sys
 from functools import lru_cache
 from itertools import cycle
 from types import ModuleType
-from typing import IO, Callable, ContextManager, List, Sequence
+from typing import IO, Iterator, List, Optional, Sequence
 
 # 3rd party
 import click
+import deprecation_alias
 from domdf_python_tools.import_tools import discover, discover_entry_points
 from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.words import SANS_SERIF_ITALIC_LETTERS
@@ -45,7 +51,8 @@ from mistletoe import block_token, span_token  # type: ignore
 from mistletoe.base_renderer import BaseRenderer  # type: ignore
 
 # this package
-from consolekit.terminal_colours import Colour, Cursor, Fore, Style, code_to_chars
+from consolekit import terminal_colours, tracebacks
+from consolekit.terminal_colours import resolve_color_default
 
 __all__ = [
 		"get_env_vars",
@@ -56,13 +63,27 @@ __all__ = [
 		"coloured_diff",
 		"solidus_spinner",
 		"braille_spinner",
+		"snake_spinner",
 		"hide_cursor",
 		"show_cursor",
 		"handle_tracebacks",
 		"traceback_handler",
 		"TerminalRenderer",
+		"hidden_cursor",
 		]
 
+# TODO: Raise deprecation warning for handle_tracebacks and traceback_handler
+
+_deprecator = deprecation_alias.deprecated(
+		deprecated_in="1.0.0",
+		removed_in="2.0.0",
+		current_version="1.1.1",
+		details="Import from consolekit.tracebacks instead."
+		)
+
+handle_tracebacks = _deprecator(tracebacks.handle_tracebacks)
+traceback_handler = _deprecator(tracebacks.traceback_handler)
+
 
 def get_env_vars(ctx, args, incomplete):  # noqa: D103
 	return [k for k in os.environ.keys() if incomplete in k]
@@ -78,7 +99,7 @@ def is_command(obj) -> bool:
 	return isinstance(obj, click.Command)
 
 
-def import_commands(source: ModuleType, entry_point: str) -> List[click.Command]:
+def import_commands(source: Optional[ModuleType] = None, entry_point: Optional[str] = None) -> List[click.Command]:
 	"""
 	Returns a list of all commands.
 
@@ -93,19 +114,29 @@ def import_commands(source: ModuleType, entry_point: str) -> List[click.Command]
 	:param entry_point:
 	"""
 
-	local_commands = discover(source, is_command, exclude_side_effects=False)
-	third_party_commands = discover_entry_points(entry_point, is_command)
-	return [*local_commands, *third_party_commands]
+	all_commands = []
+
+	if source is not None:
+		all_commands.extend(discover(source, is_command, exclude_side_effects=False))
+	if entry_point is not None:
+		all_commands.extend(discover_entry_points(entry_point, is_command))
+
+	return all_commands
 
 
-def abort(message: str) -> Exception:
+# TODO: Turn this into a class so the message is only printed when raised.
+def abort(message: str, colour: bool = None) -> Exception:
 	"""
 	Aborts the program execution.
 
 	:param message:
+	:param colour: Whether to use coloured output. Default auto-detect.
+	:no-default colour:
+
+	.. versionchanged:: 1.1.1  Added the ``colour`` option.
 	"""
 
-	click.echo(Fore.RED(message), err=True)
+	click.echo(terminal_colours.Fore.RED(message), err=True, color=resolve_color_default(colour))
 	return click.Abort()
 
 
@@ -119,7 +150,7 @@ def overtype(*objects, sep: str = ' ', end: str = '', file: IO = None, flush: bo
 	All non-keyword arguments are converted to strings like :class:`str` does and written to the stream,
 	separated by `sep` and followed by `end`.
 
-	If no objects are given, :func:`~consolekit.terminal.overtype` will just write ``"\\r"``.
+	If no objects are given, :func:`~consolekit.utils.overtype` will just write ``"\\r"``.
 
 	.. TODO:: This does not currently work in the PyCharm console, at least on Windows
 
@@ -145,8 +176,8 @@ def coloured_diff(
 		tofiledate: str = '',
 		n: int = 3,
 		lineterm: str = '\n',
-		removed_colour: Colour = Fore.RED,
-		added_colour: Colour = Fore.GREEN,
+		removed_colour: terminal_colours.Colour = terminal_colours.Fore.RED,
+		added_colour: terminal_colours.Colour = terminal_colours.Fore.GREEN,
 		) -> str:
 	r"""
 	Compare two sequences of lines; generate the delta as a unified diff.
@@ -218,101 +249,74 @@ def coloured_diff(
 
 solidus_spinner = cycle("|/-\\")
 """
-:class:`itertools.cycle` of characters to use as a loading spinner.
+:func:`itertools.cycle` of characters to use as a loading spinner.
 
 .. versionadded:: 0.7.0
 """
 
 braille_spinner = cycle("⢿ ⣻ ⣽ ⣾ ⣷ ⣯ ⣟ ⡿ ".split(' '))
 """
-:class:`itertools.cycle` of braille characters to use as a loading spinner.
+:func:`itertools.cycle` of braille characters to use as a loading spinner.
 
 .. versionadded:: 0.7.0
 """
 
+snake_spinner = cycle(['⠋', '⠙', '⠹', '⠸', '⠼', '⠴', '⠦', '⠧', '⠇', '⠏'])
+"""
+:func:`itertools.cycle` of braille characters to use as a loading spinner which looks like a snake.
+
+.. versionadded:: 1.1.1
+"""
+
 
 def hide_cursor() -> None:
 	"""
-	Hides the cursor.
+	Hide the cursor.
+
+	To show it again use :func:`~.show_cursor`,
+	or use the :func:`~.hidden_cursor` context manager.
 
 	.. versionadded:: 0.7.0
 	"""
 
-	click.echo(Cursor.HIDE)
+	click.echo(
+			terminal_colours.Cursor.HIDE(),
+			nl=False,
+			color=terminal_colours.resolve_color_default(),
+			)
 
 
 def show_cursor() -> None:
 	"""
-	Shows the cursor.
+	Show the cursor.
+
+	.. seealso:: The  :func:`~.hidden_cursor` context manager.
 
 	.. versionadded:: 0.7.0
 	"""
 
-	click.echo(Cursor.SHOW)
-
-
-nullcontext: Callable[..., ContextManager]
-
-if sys.version_info < (3, 7):  # pragma: no cover (py37+)
-
-	@contextlib.contextmanager
-	def nullcontext():
-		yield
-else:  # pragma: no cover (<py37)
-	nullcontext = contextlib.nullcontext
+	click.echo(
+			terminal_colours.Cursor.SHOW(),
+			nl=False,
+			color=terminal_colours.resolve_color_default(),
+			)
 
 
 @contextlib.contextmanager
-def traceback_handler():
+def hidden_cursor() -> Iterator:
 	"""
-	Context manager to abort execution with a short error message on the following exception types:
+	Context manager to hide the cursor for the scope of the ``with`` block.
 
-	* :exc:`FileNotFoundError`
-	* :exc:`FileExistsError`
+	.. versionadded:: 0.7.0
 
-	Other custom exception classes inheriting from :exc:`Exception` are also handled,
-	but with a generic message.
-
-	The following exception classes are ignored:
-
-	* :exc:`EOFError`
-	* :exc:`KeyboardInterrupt`
-	* :exc:`click.exceptions.ClickException`
-
-	.. versionadded:: 0.8.0
-
-	.. seealso:: :func:`~.handle_tracebacks`.
-	"""  # noqa: D400
+	.. versionchanged:: 0.9.0  Moved to :mod:`consolekit.utils`.
+	"""
 
 	try:
+		hide_cursor()
 		yield
-	except (EOFError, KeyboardInterrupt, click.ClickException, click.Abort):
-		raise
-	except FileNotFoundError as e:
-		raise abort(f"File Not Found: {e}")
-	except FileExistsError as e:
-		raise abort(f"File Exists: {e}")
-	except Exception as e:
-		raise abort(f"An error occurred: {e}")
-
-
-def handle_tracebacks(show_traceback: bool = False) -> ContextManager:
-	"""
-	Context manager to conditionally handle tracebacks, usually based on the value of a command line flag.
-
-	.. versionadded:: 0.8.0
-
-	:param show_traceback: If :py:obj:`True`, the full Python traceback will be shown on errors.
-		If :py:obj:`False`, only the summary of the traceback will be shown.
-		In either case the program execution will stop on error.
-
-	.. seealso:: :func:`~.traceback_handler`.
-	"""
-
-	if show_traceback:
-		return nullcontext()
-	else:
-		return traceback_handler()
+	finally:
+		show_cursor()
 
 
 @lru_cache(1)
@@ -334,7 +338,7 @@ def _pycharm_terminal():
 		#: TODO: pycharm on Windows and macOS
 		return great_grandparent_name == "pycharm.sh"
 
-	except Exception:
+	except Exception:  # pragma: no cover
 		return False
 
 
@@ -359,7 +363,7 @@ class TerminalRenderer(BaseRenderer):
 		:param token: The token to render.
 		"""
 
-		return Style.BRIGHT(self.render_inner(token))
+		return terminal_colours.Style.BRIGHT(self.render_inner(token))
 
 	def render_emphasis(self, token: span_token.Emphasis) -> str:
 		"""
@@ -372,7 +376,11 @@ class TerminalRenderer(BaseRenderer):
 			# Pycharm terminal doesn't support italic escape
 			return SANS_SERIF_ITALIC_LETTERS(self.render_inner(token))
 
-		return f"{code_to_chars(3)}{self.render_inner(token)}{code_to_chars(23)}"
+		return ''.join([
+				terminal_colours.code_to_chars(3),
+				self.render_inner(token),
+				terminal_colours.code_to_chars(23),
+				])
 
 	def render_inline_code(self, token: span_token.InlineCode) -> str:
 		r"""
